@@ -1,5 +1,8 @@
 use Map::Metro::Standard::Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Cmd::Graphviz
+
 class Map::Metro::Cmd::Graphviz extends Map::Metro::Cmd using Moose {
 
     use MooseX::App::Command;
@@ -124,3 +127,38 @@ class Map::Metro::Cmd::Graphviz extends Map::Metro::Cmd using Moose {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Map::Metro::Cmd::Graphviz
+
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
