@@ -1,8 +1,10 @@
 use Map::Metro::Standard;
 
+our $VERSION = '0.2200'; # VERSION
+
 package Map::Metro::Emitter {
-$Map::Metro::Emitter::VERSION = '0.2101';
-use Moose;
+
+    use Moose;
     use Kavorka;
     use List::AllUtils 'none';
     use Types::Standard -types;
@@ -79,3 +81,38 @@ use Moose;
         }
     }
 }
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Map::Metro::Emitter
+
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
