@@ -1,10 +1,13 @@
 use 5.20.0;
 use warnings;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Exception
+
 # Insired by Throwable::X
 package Map::Metro::Exception {
-$Map::Metro::Exception::VERSION = '0.2101';
-use Moose::Role;
+
+    use Moose::Role;
     use Throwable::X::Types;
 
     use namespace::clean -except => 'meta';
@@ -41,3 +44,38 @@ use Moose::Role;
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Map::Metro::Exception
+
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
