@@ -1,5 +1,9 @@
 use Map::Metro::Standard::Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Graph::Connection
+# ABSTRACT: What is a line?
+
 class Map::Metro::Graph::Connection using Moose {
 
     has origin_line_station => (
@@ -32,11 +36,17 @@ class Map::Metro::Graph::Connection using Moose {
 
 __END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Map::Metro::Graph::Connection - What is a connection?
+Map::Metro::Graph::Connection - What is a line?
+
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
 
 =head1 DESCRIPTION
 
@@ -45,17 +55,23 @@ travelling between them.
 
 In L<Graph> terms, a connection is a weighted edge.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
