@@ -1,5 +1,9 @@
 use Map::Metro::Standard::Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Graph::LineStation
+# ABSTRACT: What is a line station?
+
 class Map::Metro::Graph::LineStation using Moose {
 
     has line_station_id => (
@@ -33,12 +37,18 @@ class Map::Metro::Graph::LineStation using Moose {
 
 __END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Map::Metro::Graph::LineStation - What is a line station?
 
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
 =head1 DESCRIPTION
 
 A line station is the concept of a specific L<Station|Map::Metro::Graph::Station> on a specific L<Line|Map::Metro::Graph::Line>.
@@ -49,28 +59,31 @@ A line station is the concept of a specific L<Station|Map::Metro::Graph::Station
 
 Returns the internal line station id. Do not depend on this between executions.
 
-
 =head2 station()
 
 Returns the L<Station|Map::Metro::Graph::Station> object.
 
-
 =head2 line()
 
-eturns the L<Line|Map::Metro::Graph::Line> object.
+Returns the L<Line|Map::Metro::Graph::Line> object.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
 
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
