@@ -1,5 +1,9 @@
 use Map::Metro::Standard::Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Graph::Step
+# ABSTRACT: What is a step?
+
 class Map::Metro::Graph::Step using Moose {
 
     has origin_line_station => (
@@ -64,32 +68,43 @@ class Map::Metro::Graph::Step using Moose {
     }
 }
 
-
 __END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Map::Metro::Graph::Step - What is a step?
 
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
 =head1 DESCRIPTION
 
 Steps are exactly like L<Connections::Map::Metro::Graph::Connection>, in that they describe the combination of two
 specific L<LineStations|Map::Metro::Graph::LineStation>, and the 'cost' of travelling between them, but with an important
 difference: A Step is part of a specific L<Route|Map::Metro::Graph::Route>.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
