@@ -1,5 +1,9 @@
 use Map::Metro::Standard::Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Shim
+# ABSTRACT: Easily load a map file
+
 class Map::Metro::Shim using Moose  {
 
     use Map::Metro::Graph;
@@ -48,13 +52,20 @@ class Map::Metro::Shim using Moose  {
     }
 }
 
+__END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Map::Metro::Shim - Easily load a map file
 
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
 =head1 SYNOPSIS
 
     use Map::Metro::Shim;
@@ -75,17 +86,27 @@ The path to the map file.
 
 Apart from that this module works just like L<Map::Metro>.
 
+=head1 SEE ALSO
+
+L<Map::Metro>
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
