@@ -1,6 +1,9 @@
 use feature ':5.20';
 use Moops;
 
+our $VERSION = '0.2200'; # VERSION
+# PODNAME: Map::Metro::Types
+
 library  Map::Metro::Types
 
 extends  Types::Standard,
@@ -27,3 +30,38 @@ declares Connection,
     class_type Step         => { class => 'Map::Metro::Graph::Step' };
     class_type Transfer     => { class => 'Map::Metro::Graph::Transfer' };
 }
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Map::Metro::Types
+
+=head1 VERSION
+
+Version 0.2200, released 2015-01-08.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
